@@ -3,15 +3,22 @@ from bolinette.decorators import middleware
 from bolinette.exceptions import ForbiddenError, UnauthorizedError
 
 
-@middleware('auth', priority=2)
+@middleware('auth', priority=20)
 class AuthMiddleware(web.InternalMiddleware):
+    def define_options(self):
+        return {
+            'optional': self.params.bool(),
+            'fresh': self.params.bool(),
+            'roles': self.params.list(self.params.string())
+        }
+
     async def handle(self, request, params, next_func):
-        identity = self.context.jwt.verify(request, optional=self.options.get('optional', False),
-                                           fresh=self.options.get('fresh', False))
+        identity = self.context.jwt.verify(request, optional=self.options['optional'],
+                                           fresh=self.options['fresh'])
         current_user = None
         if identity is not None:
             current_user = await self.context.service('user').get_by_username(identity)
-        if 'roles' in self.options:
+        if len(self.options['roles']) > 0:
             if current_user is None:
                 raise UnauthorizedError('user.unauthorized')
             roles = self.options['roles']
